@@ -1,26 +1,8 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Franck Arrecot <franck.arrecot@gmail.com>
-   Copyright 2014 Rémi Benoit <r3m1.benoit@gmail.com>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Franck Arrecot <franck.arrecot@gmail.com>
+ * SPDX-FileCopyrightText: 2014 Rémi Benoit <r3m1.benoit@gmail.com>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "akonadicontextqueries.h"
 
@@ -44,7 +26,7 @@ ContextQueries::ContextQueries(const StorageInterface::Ptr &storage,
 
 ContextQueries::ContextResult::Ptr ContextQueries::findAll() const
 {
-    auto fetch = m_helpers->fetchItems();
+    auto fetch = m_helpers->fetchItems(const_cast<ContextQueries*>(this));
     auto predicate = [this] (const Akonadi::Item &item) {
         return m_serializer->isContext(item);
     };
@@ -55,7 +37,7 @@ ContextQueries::ContextResult::Ptr ContextQueries::findAll() const
 ContextQueries::TaskResult::Ptr ContextQueries::findTopLevelTasks(Domain::Context::Ptr context) const
 {
     Q_ASSERT(context);
-    auto fetch = m_helpers->fetchItemsForContext(context);
+    auto fetch = m_helpers->fetchItemsForContext(context, const_cast<ContextQueries*>(this));
     auto predicate = [this, context] (const Akonadi::Item &item) {
         if (!m_serializer->isContextChild(context, item))
             return false;
